@@ -1,4 +1,4 @@
-import React from 'react';
+import React, { PropTypes } from 'react';
 import Portal from 'react-portal';
 
 export default class Modal extends React.Component {
@@ -11,7 +11,7 @@ export default class Modal extends React.Component {
   }
 }
 Modal.propTypes = {
-  show: React.PropTypes.bool.isRequired
+  show: PropTypes.bool.isRequired
 };
 
 Modal.defaultProps = {
@@ -35,7 +35,7 @@ class PortedModal extends React.Component {
     return (
       <div style={{display: 'block'}}>
         <div className="modal modal-visible" role="dialog">
-          <div className={`modal-dialog ${this.props.dialogClasses}`}>
+          <div className={`modal-dialog ${this.props.dialogClasses}`} id={this.props.id}>
             <div className="modal-content">
               {this.props.children}
             </div>
@@ -47,8 +47,9 @@ class PortedModal extends React.Component {
   }
 }
 PortedModal.propTypes = {
-  children: React.PropTypes.node,
-  dialogClasses: React.PropTypes.string.isRequired
+  children: PropTypes.node,
+  dialogClasses: PropTypes.string.isRequired,
+  id: PropTypes.string
 };
 
 PortedModal.defaultProps = {
